/*
 * COPYRIGHT LICENSE: This information contains sample code provided in source code form. 
 * You may copy, modify, and distribute these sample programs in any form without payment
 * to IBM for the purposes of developing, using, marketing or distributing application
 * programs conforming to the application programming interface for the operating platform
 * for which the sample code is written. Notwithstanding anything to the contrary,
 * IBM PROVIDES THE SAMPLE SOURCE CODE ON AN "AS IS" BASIS AND IBM DISCLAIMS ALL WARRANTIES,
 * EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, ANY IMPLIED WARRANTIES OR CONDITIONS OF
 * MERCHANTABILITY, SATISFACTORY QUALITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE, AND ANY
 * WARRANTY OR CONDITION OF NON-INFRINGEMENT. IBM SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR OPERATION OF THE SAMPLE
 * SOURCE CODE. IBM HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS OR
 * MODIFICATIONS TO THE SAMPLE SOURCE CODE.

 * (C) Copyright IBM Corp. 2001, 2011.
 * All Rights Reserved. Licensed Materials - Property of IBM.
 */

package com.ibm.ws.jsf.sample.templating.converter;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.FacesConverter;

import com.ibm.ws.jsf.sample.templating.PhoneNumber;

@FacesConverter(value = "com.ibm.ws.jsf.sample.templating.converter.PhoneNumberConverter", forClass = com.ibm.ws.jsf.sample.templating.PhoneNumber.class)
public class PhoneNumberConverter implements Converter {
    
    @Override
    public String getAsString(FacesContext context, UIComponent component, Object value) {
        if (value == null) {
            return new String("");
        } else {
            return value.toString();
        }
    }

    @Override
    public Object getAsObject(FacesContext context, UIComponent component, String value) {
        
        PhoneNumber phoneNumber = new PhoneNumber();
          
        //for this sample we'll just assume all phone numbers are stored 10 digits long and do not contain any formatting yet (e.g. 1234567890)

        
        if (value != null) {
            if (value.contains("(") || value.contains(")") || value.contains("-")) {
                //assume it's already in the proper format
                phoneNumber.setAsIs(value);
            } else if (value.length() == 10) {
                phoneNumber.setAreaCode(value.substring(0,3));
                phoneNumber.setThreeBeforeDash(value.substring(3,6));
                phoneNumber.setFourAfterDash(value.substring(6,10));
            } else {
            //The numbers weren't as expected, we'll just set it as is
                if (value == null) {
                    value = "";
                }
                phoneNumber.setAsIs(value);
            }
        }

        return phoneNumber;
        
    }

}

